@@ -93,8 +93,8 @@ class DumpResultSqlite(DumpResult):
 			sqlite_path,
 			detect_types=sqlite3.PARSE_DECLTYPES)
 
-		self.cursor = self.sqlite_conn.cursor()
-		insert_into_db, update_in_db, get_obj_from_db = create_schema(self.cursor,
+		insert_into_db, update_in_db, get_obj_from_db = create_schema(
+			self.sqlite_conn,
 			[
 				("lines", "pickle"),
 				("parents", "pickle")
@@ -124,7 +124,7 @@ class DumpResultSqlite(DumpResult):
 
 		for key in insert_keys:
 			# create a new saved copy in the db:
-			self.insert_into_db(self.cursor,
+			self.insert_into_db(
 				(
 					self.targets[key],
 					self.to_insert[key],
@@ -139,10 +139,10 @@ class DumpResultSqlite(DumpResult):
 
 		for key in update_keys:
 			# get previous saved copy:
-			old_key, lines, parents  = self.get_obj_from_db(self.cursor, self.targets[key])
+			old_key, lines, parents  = self.get_obj_from_db(self.targets[key])
 
 			# update that copy
-			self.update_in_db(self.cursor,
+			self.update_in_db(
 				(
 					self.targets[key],
 					lines + self.to_update[key],
